/*
   Copyright (c) 2015 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
*/

//Includes
#include "main.h"
#include "sci.h"
#include "control.h"
#include "pu.h"
#include "gpio.h"
#include "tm_stm32f4_adc.h"
#include "stm32f4xx_tim.h"

//globals for LED blinking
uint16_t toggleCounter = 0x00;
uint16_t toggleMax = 5000;

//Private function prototypes
void initControlDispatcher(void);
void CheckLinkStatus(void);
extern void InitOverrideProbes(void);

/**
  * @brief  This function handles the Control/Timer Interrupt.
  * @param  None
  * @retval None
  */
void myTick_Fxn(void)
{
	//Begin of tick function
	PIL_beginInterruptCall();
	
	if(toggleCounter == 0)
	{
		toggleCounter = toggleMax;
		TM_DISCO_LedToggle(LED_GREEN);
	}
	toggleCounter--;
	
	//Read Inputs
	readInputs();
  
	//Do a control step after adc calib has finished
	if (AIn.AccuCtr == 256)
	{
		controlStep();
	}
}

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
	//init GPIO for LED,Buttons,Hall,PWM,USART
	initGPIO();
	
	//Initialize Communication Interface
  initSCI(BaudRate);
  writeSCIString("\n\r\n\rStarting PIL Demo Software... ");
  writeSCIString("\n\r");
	
	//Configure PIL Framework
  PIL_init();
  PIL_setLinkParams(PIL_D_Guid, pollSCI);
  PIL_setCtrlCallback(PilCallback);

  //Initialize Override Probes
  InitOverrideProbes();  

  //Init Control Dispatcher
	initControlDispatcher();
	
	//Initialize control system
  initControl();

  //Start in PIL Ready Mode
  PIL_requestReadyMode();		
	
	//Infinite Loop -> Background Fnc
	while (1) 
	{
			 //Check if Comm Link is still available
			 CheckLinkStatus();
			 //system synchronous
			 PIL_backgroundCall();
   }
}

/**
  * @brief  Configure the control system, TIM3 generates a control interrupt with 100us 
  * @param  None
  * @retval None
  */
void initControlDispatcher(void)
{

  NVIC_InitTypeDef NVIC_InitStructure;
	TIM_TimeBaseInitTypeDef  TIM_TimeBaseStructure;
	uint16_t PrescalerValue = 0;

  /* TIM3 clock enable */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE);

  /* Enable the TIM3 global Interrupt */
  NVIC_InitStructure.NVIC_IRQChannel = TIM3_IRQn;
	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 1;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 3;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);

  /* Compute the prescaler value */
  PrescalerValue = (uint16_t) ((SystemCoreClock / APB1PRESCTIM) / 10000000) - 1;

  /* Time base configuration */
  TIM_TimeBaseStructure.TIM_Period = INTCTRPRD;//Results in a Control interrupt every 100us
  TIM_TimeBaseStructure.TIM_Prescaler = 0;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;

  TIM_TimeBaseInit(TIM3, &TIM_TimeBaseStructure);

  /* Prescaler configuration */
  TIM_PrescalerConfig(TIM3, PrescalerValue, TIM_PSCReloadMode_Immediate);	
   
  //TIM Interrupts enable
  TIM_ITConfig(TIM3, TIM_IT_Update , ENABLE);
	//Enable Timer 3
	TIM_Cmd(TIM3, ENABLE);
}

/**
  * @brief  Check Link Status -> Green LED for ok 
  * @param  None
  * @retval None
  */
void CheckLinkStatus(void)
{
#ifdef USE_USART
			 /* Turn on ORANGE led */
          TM_DISCO_LedOn(LED_ORANGE);		
#else
			 /* USB configured OK, drivers OK */
       if (TM_USB_VCP_GetStatus() == TM_USB_VCP_CONNECTED) {
          /* Turn on ORANGE led */
          TM_DISCO_LedOn(LED_ORANGE);						            
       } else {
           /* USB not OK */					  
					TM_DISCO_LedOff(LED_ORANGE);
       }
#endif
}
