/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#ifndef CONTROL_H_
#define CONTROL_H_

#include "pil.h"

/* control tasks globals */
struct CONTROL_VARS {
	PIL_READ_PROBE(uint16_t, backgroundTaskNumber, 0, 1.0, "");
	PIL_READ_PROBE(uint16_t, task1StepCtr, 0, 1.0, "");
	PIL_READ_PROBE(uint16_t, task2StepCtr, 0, 1.0, "");

	PIL_READ_PROBE(uint16_t, Fs, 0, 1, "");
	PIL_OVERRIDE_PROBE(int16_t, Vsmax, Q_IV, VP_REF, "V");
	PIL_OVERRIDE_PROBE(int16_t, IdSet, Q_IV, I_REF, "A");
	PIL_OVERRIDE_PROBE(int16_t, IqSet, Q_IV, I_REF, "A");
	PIL_OVERRIDE_PROBE(int16_t, we, PLX_PIDQ_Q_WE, W_REF, "");
	PIL_OVERRIDE_PROBE(int16_t, IdErr, Q_IV, I_REF, "A");
	PIL_OVERRIDE_PROBE(int16_t, IqErr, Q_IV, I_REF, "A");
	PIL_OVERRIDE_PROBE(int16_t, Ia, Q_IV, I_REF, "A");
	PIL_OVERRIDE_PROBE(int16_t, Ib, Q_IV, I_REF, "A");
	PIL_OVERRIDE_PROBE(int16_t, Id, Q_IV, I_REF, "A");
	PIL_OVERRIDE_PROBE(int16_t, Iq, Q_IV, I_REF, "A");
	PIL_READ_PROBE(int16_t, Vd, Q_IV, VP_REF, "V");
	PIL_READ_PROBE(int16_t, Vq, Q_IV, VP_REF, "V");
	PIL_READ_PROBE(int16_t, VdSat, Q_IV, VP_REF, "V");
	PIL_READ_PROBE(int16_t, VqSat, Q_IV, VP_REF, "V");
	PIL_OVERRIDE_PROBE(int16_t, Va, Q_IV, VP_REF, "V");
	PIL_OVERRIDE_PROBE(int16_t, Vb, Q_IV, VP_REF, "V");
	PIL_READ_PROBE(uint16_t, CmpU, 0, 1, "");
	PIL_READ_PROBE(uint16_t, CmpV, 0, 1, "");
	PIL_READ_PROBE(uint16_t, CmpW, 0, 1, "");
	PIL_OVERRIDE_PROBE(int16_t, svpwmLimitingGain, 14, 1, "");
	PIL_OVERRIDE_PROBE(uint16_t, fluxPosition, 16, 1, "rev");
	PIL_READ_PROBE(int16_t, fluxPosSin, 15, 1, "");
	PIL_READ_PROBE(int16_t, fluxPosCos, 15, 1, "");
};

extern struct CONTROL_VARS ControlVars;

extern void InitControl(void);
extern void DisableActuation(void);
extern void EnableActuation(void);
extern void ResetControl(void);

extern void ControlTask1(void);
extern void ControlTask2(void);
extern void ControlBackground(void);


#endif /*CONTROL_H_*/
