/*
 Copyright (c) 2014 by Plexim GmbH
 All rights reserved.

 NOTICE: This software embodies unpublished proprietary
 and trade secret information of Plexim GmbH.  Any copying,
 disclosure or transmission not expressly authorized by
 the owner is expressly prohibited. Plexim GmbH retains exclusive
 ownership of all intellectual property rights in this software,
 including all copyright, trade secret and patent rights.
 */

/**
 * @file svpwm.h
 * @brief Three-level space-vector modulation module.
 */

#ifndef SVPWM3L_H_
#define SVPWM3L_H_

#include "plx_types.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef struct PLX_SVPWM3L_OBJ
{
	int32_t data[16];
} PLX_SVPWM3L_Obj_t;

typedef PLX_SVPWM3L_Obj_t *PLX_SVPWM3L_Handle_t;

extern PLX_SVPWM3L_Handle_t PLX_SVPWM3L_init(void *aMemory, const size_t aNumBytes);

extern void PLX_SVPWM3L_configure(PLX_SVPWM3L_Handle_t aHandle, uint16_t aCounterPeriod);

extern void PLX_SVPWM3L_calcCompareValues(PLX_SVPWM3L_Handle_t aHandle,
		int16_t aVa, int16_t aVb, int16_t aVdc,
		uint16_t aRedVect1Split, uint16_t aRedVect2Split, // redundant vector 2 is center of sub-hexagon
		uint16_t *aCmp0, uint16_t *aCmp1, uint16_t *aCmp2, uint16_t *aCmp3, uint16_t *aCmp4, uint16_t *aCmp5,
		int16_t *aLimiting);

extern void PLX_SVPWM3L_getSector(PLX_SVPWM3L_Handle_t aHandle, uint16_t *aSubHexagon, uint16_t *aZone);

extern void PLX_SVPWM3L_getVabT(PLX_SVPWM3L_Handle_t aHandle, int16_t *aVaT, int16_t *aVbT);

extern void PLX_SVPWM3L_getCmprT(PLX_SVPWM3L_Handle_t aHandle, uint16_t *aCmp0, uint16_t *aCmp1, uint16_t *aCmp2);

#ifdef __cplusplus
}
#endif // extern "C"

#endif /* SVPWM3L_H_ */
