<?php
/*
 *  general_functions.php
 *
 *  Copyright (c) 2014 Plexim GmbH. All rights reserved.
 *
 * $Rev: 15734 $
 * $Date: 2015-08-18 13:02:33 +0200 (Tue, 18 Aug 2015) $
 */

$post_data = json_decode(file_get_contents('php://input'), true);

if (isset($_GET['PHPSESSID']))
   session_id($_GET['PHPSESSID']);
elseif (isset($post_data['PHPSESSID']) and $post_data['PHPSESSID'])
   session_id($post_data['PHPSESSID']);
session_start();

$xmlrpc_inc = '../private/xmlrpc.inc';
file_exists($xmlrpc_inc) or
   exit(json_encode(array('errorMsg'=>
		  htmlspecialchars("Error: File not found: ".$xmlrpc_inc))));
require $xmlrpc_inc;
$xmlrpc_internalencoding = "UTF-8";


function getConfigIni()
{
   if (!isset($_SESSION['config_ini']) || $_SESSION['config_ini']['develop'])
   {
      $configFilename = '../private/config.ini';
      if (!file_exists($configFilename))
         $errorMsg = "Error: Config file not found: $configFilename\n";
      else
      {
         $config_ini = parse_ini_file($configFilename);
         if (empty($config_ini))
            $errorMsg = "Error: Config file not found: $configFilename\n";
         else
         {
            if (!isset($config_ini['expirytime'])) 
               $config_ini['expirytime'] = 3600;
            if (!isset($config_ini['develop'])) 
               $config_ini['develop'] = false;
            $_SESSION['config_ini'] = $config_ini;
            return;
         }
      }
      error_log("PHP Error\n".$errorMsg."");
      exit(json_encode(array('errorMsg' => htmlspecialchars($errorMsg))));
   }
}


function urlVar($name)
{
   global $post_data;

   if (isset($_GET[$name]))
      $value = urldecode($_GET[$name]);
   elseif (isset($post_data[$name]))
      $value = urldecode($post_data[$name]);
   else
      return '';
   // Input validation and type conversion
   switch ($name)
   {
      case 'modelName':
      case 'modelPath':
         return str_replace(array('\\','/',':','*','?','"','<','>','|'), '',
                preg_replace('/\p{Cc}+/u', '', $value));
         break;
      case 'action':
         // allow alphabetical characters only
         return ctype_alpha($value) ? $value : '';
         break;
      case 'traceName':
         // allow interger numbers or 'Current Trace'
         return ctype_digit($value) || !strcmp('Current Trace', $value) ? $value : '';
         break;
      case 'analysisName':
         // remove control characters from UTF-8 string
         return preg_replace('/\p{Cc}+/u', '', $value);
         break;
      case 'icon':
         return ctype_alnum(str_replace(array('_'), '', $value)) ? $value : '';
         break;
      case 'width':
      case 'height':
      case 'resolution':
      case 'scopeIdx':
      case 'schematicIdx':
      case 'configurationIdx':
         // allow digits only only and return integer type
         return ctype_digit($value) ? (int) $value : '';
         break;
      case 'args':
      case 'traceNames':
      case 'view':
         // decode JSON object into PHP array and return it
         return json_decode($value, true);
         break;
      default:
         return '';
   }
}


function fullModelName()
{
   $modelName = urlVar('modelName');
   $modelPath = urlVar('modelPath');
   if (strlen($modelPath) > 0)
      $modelPath .= '/';
   return $modelPath.$modelName;
}

function uniqueModelName()
{
   return isset($_SESSION['models'][fullModelName()]['uniqueModelName']) ?
      $_SESSION['models'][fullModelName()]['uniqueModelName'] : '';
}

function plecsWebserver($cmd, $obj, $args = array())
{
   if (!isset($_SESSION['config_ini']))
      return array('errorMsg' => 'Your session has expired. Please reload.');

   $client = new xmlrpc_client("/RPC2", $_SESSION['config_ini']['host'],
                               $_SESSION['config_ini']['port']);
   $opts = array(php_xmlrpc_encode($cmd),
                 php_xmlrpc_encode($obj));
   if (empty($args))
      $opts[] = new xmlrpcval(array(), "struct");
   else
      $opts[] = php_xmlrpc_encode($args);
   $request = new xmlrpcmsg('plecs.webserver', $opts);
   $res = $client->send($request);
   if (!$res->faultCode())
      return php_xmlrpc_decode($res->value());
   else
   {
      if (!preg_match('/Invalid (model name|scope path)\./', $res->faultString()))
      {
         error_log("PLECS Error: ".htmlentities($res->faultCode())
            . "\nReason:  '".htmlentities($res->faultString())
            ."'\nModel  : '".fullModelName()
            ."'\nCommand: '".$cmd
            ."'\nObject:  '".$obj
            ."'\nArguments:\n".print_r($args, true));
      }
      $faultString = $res->faultString();
      if (uniqueModelName())
         $faultString = str_replace(uniqueModelName().'/', '', $faultString);
      $faultString = str_replace('Simulation error: Error: ', 'Simulation error: ', $faultString);
      $faultString = str_replace('method execution error: ', '', $faultString);
      $faultString = preg_replace('/Invalid (model name|scope path)\./', 'Your session has expired. Please reload.', $faultString);
      $faultString = preg_replace('/Connect error: .*/', 'The simulation server is currently unavailable.', $faultString);
      return array('errorMsg' => htmlspecialchars($faultString));
   }
}

function plecsScope($scopePath, $cmd, $addArgs)
{
   if (!isset($_SESSION['config_ini']))
      return array('errorMsg' => 'Your session has expired. Please reload.');

   $client = new xmlrpc_client("/RPC2", $_SESSION['config_ini']['host'],
                               $_SESSION['config_ini']['port']);
   $args = array(php_xmlrpc_encode($scopePath),
                 php_xmlrpc_encode($cmd));
   if (isset($addArgs))
      $args[] = php_xmlrpc_encode($addArgs);
   $request = new xmlrpcmsg('plecs.scope', $args);
   $client->send($request);
}



function plecsXml($cmd, $args)
{
   if (!isset($_SESSION['config_ini']))
      return array('errorMsg' => 'Your session has expired. Please reload.');

   $client = new xmlrpc_client("/RPC2", $_SESSION['config_ini']['host'],
                               $_SESSION['config_ini']['port']);
   $opts = array(php_xmlrpc_encode($args));
   $request = new xmlrpcmsg($cmd, $opts);
   $res = $client->send($request);
   if (!$res->faultCode())
      return php_xmlrpc_decode($res->value());
   else
   {
      if (!preg_match('/Invalid (model name|scope path)\./', $res->faultString()))
      {
         error_log("PLECS Error: ".htmlentities($res->faultCode())
            . "\nReason:  '".htmlentities($res->faultString())
            ."'\nModel  : '".fullModelName()
            ."'\nCommand: '".$cmd
            ."'\nArguments:\n".print_r($args, true));
      }
      return array('errorMsg' => 'Your session has expired. Please reload.');
   }
}

?>